@@ -257,7 +257,7 @@ def get_value_from_array(data_arr_input, low_li, up_li):
 
 def main():
     parser = argparse.ArgumentParser(prog='vinset', description='VINSET package.')
-    parser.add_argument('--version', action='version', version='3.0.2'),
+    parser.add_argument('--version', action='version', version='3.0.3'),
     parser.add_argument("-i", dest="input_filename", required=True, type=argparse.FileType('r'), default=sys.stdin,
                         help="input mp4 file", metavar="filename.mp4")
     parser.add_argument("-d", dest="input_data_filename", required=True, type=argparse.FileType('r'), default=sys.stdin,
@@ -389,7 +389,7 @@ def main():
                     time_interval_for_data = round(1000 / (axes_pos_w / t_w), 4)
                     number_of_time_interval = math.ceil(max_video_length / time_interval_for_data)
                     lower_range = 0
-                    upper_range = round((lower_range + time_interval_for_data), 2) * 10
+                    upper_range = round((lower_range + time_interval_for_data), 2)
                     width_check = int(t_w) * 1000
                     box_data_array = []
                     for i in range(1, (number_of_time_interval + 1), 1):
@@ -594,8 +594,8 @@ def main():
                             end_x = 0
                             end_y = 0
                             final_display_arr = display_arr[display_count][1]
-                            pointer_x = 0
-                            pointer_y = 0
+                            # pointer_x = 0
+                            # pointer_y = 0
                             check_timer_input = check_timer - (display_count * t_width * 1000)
                             drawable_limit = ax_x + int((check_timer_input / (time_interval_for_data * 1000)))
                             pen_draw = False
